==> haskell-djinn-ghc-0.0.2.3-84-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-ghc
version:              0.0.2.3
visibility:           public
id:                   djinn-ghc-0.0.2.3-L7VBB5VfzL2E4GBprTXSM2
key:                  djinn-ghc-0.0.2.3-L7VBB5VfzL2E4GBprTXSM2
license:              BSD-3-Clause
maintainer:           trupill@gmail.com   
author:               Alejandro Serrano
synopsis:
    Generate Haskell code from a type. Bridge from Djinn to GHC API.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is the bridge from djinn-lib to GHC API.

category:             Language
abi:                  2dbc7d70dfbf7f41cda27d131a4b4100
exposed:              True
exposed-modules:      Djinn.GHC
import-dirs:          /usr/lib/ghc-8.10.3/site-local/djinn-ghc-0.0.2.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/djinn-ghc-0.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/djinn-ghc-0.0.2.3
hs-libraries:         HSdjinn-ghc-0.0.2.3-L7VBB5VfzL2E4GBprTXSM2
depends:
    async-2.2.2-Ga7skT6sa0M3xMboL4eTgj base-4.14.1.0 containers-0.6.2.1
    djinn-lib-0.0.1.3-5XQMRIW3Cz21joN2SK3nHm ghc-8.10.3 mtl-2.2.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-djinn-ghc/html/djinn-ghc.haddock
haddock-html:         /usr/share/doc/haskell-djinn-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djinn-ghc-0.0.2.3-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-djinn-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 djinn-ghc
version:              0.0.2.3
visibility:           public
id:                   djinn-ghc-0.0.2.3-6pegA4YqAAxEcOZ67jdng2
key:                  djinn-ghc-0.0.2.3-6pegA4YqAAxEcOZ67jdng2
license:              BSD-3-Clause
maintainer:           trupill@gmail.com   
author:               Alejandro Serrano
synopsis:
    Generate Haskell code from a type. Bridge from Djinn to GHC API.

description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is the bridge from djinn-lib to GHC API.

category:             Language
abi:                  f6fc0d3012de085fe373556ec1ed08df
exposed:              True
exposed-modules:      Djinn.GHC
import-dirs:          /usr/lib/ghc-8.10.4/site-local/djinn-ghc-0.0.2.3
library-dirs:         /usr/lib/ghc-8.10.4/site-local/djinn-ghc-0.0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/djinn-ghc-0.0.2.3
hs-libraries:         HSdjinn-ghc-0.0.2.3-6pegA4YqAAxEcOZ67jdng2
depends:
    async-2.2.3-7q4xz6wSWCp9WA1BmnApnS base-4.14.1.0 containers-0.6.2.1
    djinn-lib-0.0.1.3-5XQMRIW3Cz21joN2SK3nHm ghc-8.10.4 mtl-2.2.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-djinn-ghc/html/djinn-ghc.haddock
haddock-html:         /usr/share/doc/haskell-djinn-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
